/* ver.B.b16.06(BLAZE) */


#include "version.h"


VERSION ap_version = {
	"AP.code",
	"pdbstatus",
	"(C) 2000-2007 Hirohisa Mori and GLOBALBASE Project",
	"ver.B.b16.06(BLAZE)",
	2007,6,26,
	0,
	"pdb (progressive DB) status viewer ",
};

